@@ -262,24 +262,43 @@ pub fn generate(ast: &[parser::Token]) -> String {
                             );
                         }
                         "value" => {
-                            imp += &format!(
-                                "\t{}.set_value({});\n",
-                                &elem.ident,
+                            let val = if t.contains("Button") {
+                                let b = utils::unbracket(&props[i + 1]).parse::<i32>().expect("Buttons should have integral values");
+                                if b != 0 {
+                                    "true".to_string()
+                                } else {
+                                    "false".to_string()
+                                }
+                            } else if (t.contains("Input") || t.contains("Output")) && !t.contains("Value") {
                                 if unsafe { crate::parser::PROGRAM.i18n } {
                                     format!("&tr!(\"{}\")", utils::unbracket(&props[i + 1]))
                                 } else {
                                     format!("\"{}\"", utils::unbracket(&props[i + 1]))
                                 }
+                            } else {
+                                format!("{} as _", utils::unbracket(&props[i + 1]))
+                            };
+                            imp += &format!(
+                                "\t{}.set_value({});\n",
+                                &elem.ident,
+                                val
                             );
                         }
                         "type" => {
                             if props[i + 1] != "Double" && t != "MenuItem" && t != "Submenu" {
-                                imp += &format!(
-                                    "\t{}.set_type({}Type::{});\n",
-                                    &elem.ident,
-                                    utils::fix_type(t),
-                                    utils::global_to_pascal(utils::unbracket(&props[i + 1]))
-                                );
+                                if t != "Output" {
+                                    imp += &format!(
+                                        "\t{}.set_type({}Type::{});\n",
+                                        &elem.ident,
+                                        utils::fix_type(t),
+                                        utils::global_to_pascal(utils::unbracket(&props[i + 1]))
+                                    );
+                                } else {
+                                    imp += &format!(
+                                        "\t{}.set_type(InputType::from_i32(12));\n",
+                                        &elem.ident,
+                                    );
+                                }
                             }
                         }
                         "align" => {
@@ -290,11 +309,13 @@ pub fn generate(ast: &[parser::Token]) -> String {
                             );
                         }
                         "shortcut" => {
-                            imp += &format!(
-                                "\t{}.set_shortcut(unsafe {{std::mem::transmute({})}});\n",
-                                &elem.ident,
-                                utils::unbracket(&props[i + 1])
-                            );
+                            if t != "MenuItem" && t != "Submenu" {
+                                imp += &format!(
+                                    "\t{}.set_shortcut(unsafe {{std::mem::transmute({})}});\n",
+                                    &elem.ident,
+                                    utils::unbracket(&props[i + 1])
+                                );
+                            }
                         }
                         "image" => {
                             imp += &format!(
@@ -346,8 +367,13 @@ pub fn generate(ast: &[parser::Token]) -> String {
                         }
                         let parent: Vec<&str> = menu_parent.split_whitespace().collect();
                         let parent = parent[1];
+                        let shortcut = if props.contains(&"shortcut".to_string()) {
+                            Some(props[props.iter().position(|r| r == "shortcut").unwrap() + 1].clone())
+                        } else {
+                            None
+                        };
                         imp += &format!(
-                            "\t{}.add({}, Shortcut::None, MenuFlag::{}, |_| {{}});\n",
+                            "\t{}.add({}, {}, MenuFlag::{}, |_| {{}});\n",
                             parent,
                             if let Some(l) = label {
                                 if unsafe { crate::parser::PROGRAM.i18n } {
@@ -366,6 +392,11 @@ pub fn generate(ast: &[parser::Token]) -> String {
                             } else {
                                 "\"\"".to_string()
                             },
+                            if let Some(shortcut) = shortcut {
+                                format!("unsafe {{std::mem::transmute({})}}", shortcut)
+                            } else {
+                                "Shortcut::None".to_string()
+                            },
                             if let Some(ty) = typ {
                                 &props[ty + 1]
                             } else {
